==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/acp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'access_control'=>'Zugriffsregeln',
'ace_to_group'=>'für Gruppe',
'ace_to_user'=>'für Benutzer',
'acp_overview'=>'Verwalter-Konsole',
'add_a_new_group'=>'Neue Benutzergruppe hinzufügen',
'add_a_new_prefix'=>'Neuen Beitragpräfix hinzufügen',
'check_for_update'=>'Auf Software-Aktualisierung prüfen',
'choose_data'=>'Daten auswählen',
'choose_ip'=>'Begrenzen auf IP-Adresse',
'choose_level'=>'Stufe auswählen',
'choose_time'=>'Zeit auswählen',
'choose_zoom'=>'Zeitrahmen',
'color'=>'Farbe',
'configuration'=>'Einstellungen',
'currently_no_log_entries'=>'Kein Logeintrag entspricht deinen Kriterien!',
'database_version'=>'Datenbank-Version',
'database_version_is_too_old_please_upgrade'=>'Die aktuelle Softwareversion benötigt eine neuere Datenbankstruktur als du hast. Bitte starte die Installation erneut und aktualisiere deine Datenbank.',
'delete_ace_successful'=>'Der Eintrag wurde aus den Zugriffsregeln entfernt.',
'delete_group_successful'=>'Die Benutzergruppe wurde gelöscht.',
'delete_prefix_successful'=>'Der Beitragpräfix wurde gelöscht.',
'edit_acl'=>'Regeln festlegen',
'edit_acl_successful'=>'Die Zugriffsregeln wurden geändert.',
'edit_cfg'=>'Optionen festlegen',
'edit_cfg_successful'=>'Deine Einstellungen wurden geändert.',
'edit_group'=>'Benutzergruppe ändern',
'edit_group_acl'=>'Gruppen-Zugriffe ändern',
'edit_group_normal'=>'Normale Gruppendaten ändern',
'edit_group_successful'=>'Die Benutzergruppe wurde geändert.',
'edit_prefix'=>'Präfix ändern',
'edit_prefix_successful'=>'Der Beitragpräfix wurde geändert.',
'edit_task'=>'Aufgabe ändern',
'edit_task_successful'=>'Die Aufgabe wurde geändert.',
'explain_choose_ip'=>'Ergebnisse auf eine IP-Adresse begrenzen?',
'explain_choose_level'=>'Ergebnisse auf eine Stufe begrenzen?',
'explain_choose_time'=>'Wähle eine Zeit aus.',
'explain_group_color'=>'Diese Farbe wird benutzt, um die Benutzergruppe kenntlich zu machen.',
'explain_group_name'=>'Gebe den Namen der Benutzergruppe an.',
'explain_group_permission_copy'=>'Wähle eine Benutzergruppe aus von der du die Zugriffsregeln für die neue kopieren möchtest.',
'explain_group_permission_ex'=>'Möchtest du der Benutzergruppe Verwalterrechte erteilen?',
'explain_group_permission_pa'=>'Sollen neue Beiträge sofort freigegeben sein?',
'explain_group_permission_pr'=>'Ist es dieser Benutzergruppe erlaubt wiederholt Beiträge zu verfassen?',
'explain_group_permission_ra'=>'Darf diese Benutzergruppe nicht freigegebene Beiträge lesen?',
'explain_group_post_weight'=>'Maximales Gewicht für jeden Beitrag.',
'explain_list_as_request'=>'Sollen Beiträge mit diesem Präfix auf der Moderator- und Verwalter-Konsole unter den "ausstehenden Anfragen" aufgelistet werden?',
'explain_order_by'=>'Lege fest wie die Ergebnisse sortiert sein sollen.',
'explain_prefix_acl'=>'Falls dieser Präfix einem Beitrag zugeordnet wird, vererbt er die Zugriffsregel an diesen.',
'explain_prefix_name'=>'Wähle den Namen des Präfix.',
'explain_task_interval'=>'Nach welchem Intervall soll diese Aufgabe ausgeführt werden? Wert: <u>Sekunden</u>',
'explain_user'=>'Ergebnisse auf einen Benutzer begrenzen?',
'forum_is_not_running'=>'Dieses Forum befindet sich im Wartungsmodus. Nur priviligierte Benutzer können darauf zugreifen.',
'group_id'=>'Gruppen-ID',
'group_is_not_empty'=>'Dieser Benutzergruppe sind noch Benutzer zugeordnet.',
'group_permission_copy'=>'Zugriffsregeln dieser Gruppe kopieren',
'group_permission_ex'=>'Gruppenrecht: Verwaltung',
'group_permission_pa'=>'Gruppenrecht: Beitrag freigeschaltet',
'group_permission_pr'=>'Gruppenrecht: Wiederholtes Schreiben',
'group_permission_ra'=>'Gruppenrecht: Versteckte Beiträge lesen',
'group_post_weight'=>'Höchtes Beitraggewicht',
'installed_new_task'=>'Die folgenden Aufgaben hinzugefügt',
'ip_address'=>'IP-Adresse',
'list_as_request'=>'Als Anfrage auflisten',
'log_action'=>'Aktion',
'log_info'=>'Information',
'log_level'=>'Stufe',
'log_level_both'=>'Beide',
'log_level_error'=>'Fehler',
'log_level_info'=>'Hinweis',
'log_level_system'=>'Kern-Ebene',
'log_text'=>'Nachricht',
'log_view'=>'Protokoll-Ansicht',
'monthly'=>'Monatlich',
'new_ace'=>'Neuen Benutzer der Liste hinzufügen',
'new_ace_successful'=>'Eine Zugriffsregel wurde hinzugefügt.',
'new_forum_software_version_available'=>'Der Aktualisierungsserver meldet, daß <a href="%s" target="_blank">eine neue Version (%s)</a> zur Verfügung steht.',
'new_group_successful'=>'Eine neue Benutzergruppe wurde hinzugefügt.',
'new_prefix_successful'=>'Ein neuer Beitragpräfix wurde hinzugefügt.',
'next_task'=>'Nächste Geplante Aufgabe',
'no_new_task_found'=>'Keine neuen Aufgaben gefunden...',
'php_version'=>'PHP-Version',
'please_select_action'=>'Bitte wähle eine Aktion zur Bearbeitung aus',
'please_select_class'=>'Bitte wähle eine Abschnitt der Einstellungen zur Bearbeitung aus',
'please_select_group'=>'Bitte wähle eine Benutzergruppe zur Bearbeitung aus',
'please_select_prefix'=>'Bitte wähle einen Beitragpräfix zur Bearbeitung aus',
'please_select_task'=>'Bitte wähle eine Aufgabe zur Bearbeitung aus',
'post_prefix'=>'Beitragpräfix',
'prefix_acl'=>'Zugriffregel-Voreinstellung',
'prefix_is_not_empty'=>'Dieser Beitragpräfix hat noch zugeordnete Beiträge.',
'purge_acl_cache'=>'Zugriffsregeln-Zwischenspeicher löschen',
'purge_main_cache'=>'Haupt-Zwischenspeicher löschen',
'quick_overview'=>'Kürzlich fand statt...',
'run_soonest'=>'frühestens am',
'scan_for_new_task'=>'Nach neuen Aufgaben suchen',
'scheduled_task'=>'Geplante Aufgabe',
'select_color'=>'Farbe auswählen',
'select_time'=>'Zeit auswählen',
'statistic'=>'Statistik',
'statistic_data_account'=>'Registrierte Benutzerkonten',
'statistic_data_exception'=>'Software-Ausnahmefehler',
'statistic_data_login'=>'Anzahl der Anmeldungen',
'statistic_data_password'=>'Angeforderte Passwörter',
'statistic_data_posting'=>'Verfasste Beiträge',
'statistic_data_search'=>'Suchanfragen',
'stat_post_total'=>'Aktuell verfügbare Beiträge',
'stat_user_registered_today'=>'Heute registrierte Benutzer',
'stat_user_request_total'=>'Anzahl der ausstehenden Benutzeranfragen',
'stat_user_total'=>'Anzahl der registrierten Benutzerkonten',
'st_account_activation'=>'Konto aktiviert',
'st_account_register'=>'Konto registriert',
'st_exception'=>'Software-Ausnahmefehler',
'st_login_attempt'=>'Anmeldeversuch',
'st_login_success'=>'Anmeldung erfolgreich',
'st_password_activation'=>'Passwort aktiviert',
'st_password_request'=>'Passwort angefordert',
'st_search_cached'=>'Zwischengespeichertes Suchergebnis',
'st_search_query'=>'Gestellte Suchanfragen',
'st_submit_posting'=>'Verfasste Beiträge',
'task_active'=>'Ausgeführte Aufgabe',
'task_description'=>'Beschreibung',
'task_explain_optimize'=>'Optimiert deine Datenbank',
'task_explain_post_timespan'=>'Berechnet den ältesten/jüngsten Beitrag',
'task_explain_prune_log'=>'Entfernt abgelaufene Protokolleinträge aus der Datenbank',
'task_explain_prune_request'=>'Entfernt abgelaufene Benutzeranfragen aus der Datenbank',
'task_explain_prune_search'=>'Entfernt abgelaufene Suchanfragen aus der Datenbank',
'task_explain_prune_user'=>'Entfernt nicht aktivierte Benutzerkonten aus der Datenbank',
'task_info'=>'Information über die Aufgabe',
'task_interval'=>'Startintervall',
'task_last_run'=>'Zuletzt gestartet',
'task_next_run'=>'Nächster Lauf (frühestens)',
'task_seg_optimize'=>'Aufgabe: Optimiert Forum-Datenbank',
'task_seg_post_timespan'=>'Aufgabe: Kalender auf der Übersichtseite',
'task_seg_prune_log'=>'Aufgabe: Protokoll-Aufzeichnung säubern',
'task_seg_prune_request'=>'Aufgabe: Benutzeranfragen säubern',
'task_seg_prune_search'=>'Aufgabe: Suchtabelle säubern',
'task_seg_prune_user'=>'Aufgabe: Benutzerkonten säubern',
'user_group'=>'Benutzergruppe',
'using_recent_forum_software_version'=>'Der Aktualisierungsserver meldet, daß du bereits die neueste verfügbare Version hast.',
'version'=>'Aktuelle Version',
'yearly'=>'Jährlich'
);
?>

==> larus_board-0.9.16.zip: larus_board-0.9.16/lb_private/lang/de/acp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'access_control'=>'Zugriffsregeln',
'account_successfully_deleted'=>'Dieser Benutzer wurde gelöscht.',
'ace_to_group'=>'für Gruppe',
'ace_to_user'=>'für Benutzer',
'acp_overview'=>'Verwalter-Konsole',
'add_a_new_group'=>'Neue Benutzergruppe hinzufügen',
'add_a_new_prefix'=>'Neuen Beitragpräfix hinzufügen',
'check_for_update'=>'Auf Software-Aktualisierung prüfen',
'choose_data'=>'Daten auswählen',
'choose_ip'=>'Begrenzen auf IP-Adresse',
'choose_level'=>'Stufe auswählen',
'choose_time'=>'Zeit auswählen',
'choose_zoom'=>'Zeitrahmen',
'color'=>'Farbe',
'configuration'=>'Einstellungen',
'currently_no_log_entries'=>'Kein Logeintrag entspricht deinen Kriterien!',
'database_version'=>'Datenbank-Version',
'database_version_is_too_old_please_upgrade'=>'Die aktuelle Softwareversion benötigt eine neuere Datenbankstruktur als du hast. Bitte starte die Installation erneut und aktualisiere deine Datenbank.',
'delete_ace_successful'=>'Der Eintrag wurde aus den Zugriffsregeln entfernt.',
'delete_group_successful'=>'Die Benutzergruppe wurde gelöscht.',
'delete_prefix_successful'=>'Der Beitragpräfix wurde gelöscht.',
'edit_acl'=>'Regeln festlegen',
'edit_acl_successful'=>'Die Zugriffsregeln wurden geändert.',
'edit_cfg'=>'Optionen festlegen',
'edit_cfg_successful'=>'Deine Einstellungen wurden geändert.',
'edit_group'=>'Benutzergruppe ändern',
'edit_group_acl'=>'Gruppen-Zugriffe ändern',
'edit_group_normal'=>'Normale Gruppendaten ändern',
'edit_group_successful'=>'Die Benutzergruppe wurde geändert.',
'edit_prefix'=>'Präfix ändern',
'edit_prefix_successful'=>'Der Beitragpräfix wurde geändert.',
'edit_task'=>'Aufgabe ändern',
'edit_task_successful'=>'Die Aufgabe wurde geändert.',
'explain_choose_ip'=>'Ergebnisse auf eine IP-Adresse begrenzen?',
'explain_choose_level'=>'Ergebnisse auf eine Stufe begrenzen?',
'explain_choose_time'=>'Wähle eine Zeit aus.',
'explain_group_color'=>'Diese Farbe wird benutzt, um die Benutzergruppe kenntlich zu machen.',
'explain_group_name'=>'Gebe den Namen der Benutzergruppe an.',
'explain_group_permission_copy'=>'Wähle eine Benutzergruppe aus von der du die Zugriffsregeln für die neue kopieren möchtest.',
'explain_group_permission_ex'=>'Möchtest du der Benutzergruppe Verwalterrechte erteilen?',
'explain_group_permission_pa'=>'Sollen neue Beiträge sofort freigegeben sein?',
'explain_group_permission_pr'=>'Ist es dieser Benutzergruppe erlaubt wiederholt Beiträge zu verfassen?',
'explain_group_permission_ra'=>'Darf diese Benutzergruppe nicht freigegebene Beiträge lesen?',
'explain_group_post_weight'=>'Maximales Gewicht für jeden Beitrag.',
'explain_list_as_request'=>'Sollen Beiträge mit diesem Präfix auf der Moderator- und Verwalter-Konsole unter den "ausstehenden Anfragen" aufgelistet werden?',
'explain_order_by'=>'Lege fest wie die Ergebnisse sortiert sein sollen.',
'explain_prefix_acl'=>'Falls dieser Präfix einem Beitrag zugeordnet wird, vererbt er die Zugriffsregel an diesen.',
'explain_prefix_name'=>'Wähle den Namen des Präfix.',
'explain_task_interval'=>'Nach welchem Intervall soll diese Aufgabe ausgeführt werden? Wert: <u>Sekunden</u>',
'explain_user'=>'Ergebnisse auf einen Benutzer begrenzen?',
'forum_is_not_running'=>'Dieses Forum befindet sich im Wartungsmodus. Nur priviligierte Benutzer können darauf zugreifen.',
'group_id'=>'Gruppen-ID',
'group_is_not_empty'=>'Dieser Benutzergruppe sind noch Benutzer zugeordnet.',
'group_permission_copy'=>'Zugriffsregeln dieser Gruppe kopieren',
'group_permission_ex'=>'Gruppenrecht: Verwaltung',
'group_permission_pa'=>'Gruppenrecht: Beitrag freigeschaltet',
'group_permission_pr'=>'Gruppenrecht: Wiederholtes Schreiben',
'group_permission_ra'=>'Gruppenrecht: Versteckte Beiträge lesen',
'group_post_weight'=>'Höchtes Beitraggewicht',
'installed_new_task'=>'Die folgenden Aufgaben hinzugefügt',
'ip_address'=>'IP-Adresse',
'list_as_request'=>'Als Anfrage auflisten',
'log_action'=>'Aktion',
'log_info'=>'Information',
'log_level'=>'Stufe',
'log_level_both'=>'Beide',
'log_level_error'=>'Fehler',
'log_level_info'=>'Hinweis',
'log_level_system'=>'Kern-Ebene',
'log_text'=>'Nachricht',
'log_view'=>'Protokoll-Ansicht',
'monthly'=>'Monatlich',
'new_ace'=>'Neuen Benutzer der Liste hinzufügen',
'new_ace_successful'=>'Eine Zugriffsregel wurde hinzugefügt.',
'new_forum_software_version_available'=>'Der Aktualisierungsserver meldet, daß <a href="%s" target="_blank">eine neue Version (%s)</a> zur Verfügung steht.',
'new_group_successful'=>'Eine neue Benutzergruppe wurde hinzugefügt.',
'new_prefix_successful'=>'Ein neuer Beitragpräfix wurde hinzugefügt.',
'next_task'=>'Nächste Geplante Aufgabe',
'no_new_task_found'=>'Keine neuen Aufgaben gefunden...',
'php_version'=>'PHP-Version',
'please_select_action'=>'Bitte wähle eine Aktion zur Bearbeitung aus',
'please_select_class'=>'Bitte wähle eine Abschnitt der Einstellungen zur Bearbeitung aus',
'please_select_group'=>'Bitte wähle eine Benutzergruppe zur Bearbeitung aus',
'please_select_prefix'=>'Bitte wähle einen Beitragpräfix zur Bearbeitung aus',
'please_select_task'=>'Bitte wähle eine Aufgabe zur Bearbeitung aus',
'post_prefix'=>'Beitragpräfix',
'prefix_acl'=>'Zugriffregel-Voreinstellung',
'prefix_is_not_empty'=>'Dieser Beitragpräfix hat noch zugeordnete Beiträge.',
'purge_acl_cache'=>'Zugriffsregeln-Zwischenspeicher löschen',
'purge_main_cache'=>'Haupt-Zwischenspeicher löschen',
'quick_overview'=>'Kürzlich fand statt...',
'run_soonest'=>'frühestens am',
'scan_for_new_task'=>'Nach neuen Aufgaben suchen',
'scheduled_task'=>'Geplante Aufgabe',
'select_time'=>'Zeit auswählen',
'statistic'=>'Statistik',
'statistic_data_account'=>'Registrierte Benutzerkonten',
'statistic_data_exception'=>'Software-Ausnahmefehler',
'statistic_data_login'=>'Anzahl der Anmeldungen',
'statistic_data_password'=>'Angeforderte Passwörter',
'statistic_data_posting'=>'Verfasste Beiträge',
'statistic_data_search'=>'Suchanfragen',
'stat_post_total'=>'Aktuell verfügbare Beiträge',
'stat_user_registered_today'=>'Heute registrierte Benutzer',
'stat_user_request_total'=>'Anzahl der ausstehenden Benutzeranfragen',
'stat_user_total'=>'Anzahl der registrierten Benutzerkonten',
'st_account_activation'=>'Konto aktiviert',
'st_account_register'=>'Konto registriert',
'st_exception'=>'Software-Ausnahmefehler',
'st_login_attempt'=>'Anmeldeversuch',
'st_login_success'=>'Anmeldung erfolgreich',
'st_password_activation'=>'Passwort aktiviert',
'st_password_request'=>'Passwort angefordert',
'st_search_cached'=>'Zwischengespeichertes Suchergebnis',
'st_search_query'=>'Gestellte Suchanfragen',
'st_submit_posting'=>'Verfasste Beiträge',
'task_active'=>'Ausgeführte Aufgabe',
'task_description'=>'Beschreibung',
'task_explain_optimize'=>'Optimiert deine Datenbank',
'task_explain_post_timespan'=>'Berechnet den ältesten/jüngsten Beitrag',
'task_explain_prune_log'=>'Entfernt abgelaufene Protokolleinträge aus der Datenbank',
'task_explain_prune_request'=>'Entfernt abgelaufene Benutzeranfragen aus der Datenbank',
'task_explain_prune_search'=>'Entfernt abgelaufene Suchanfragen aus der Datenbank',
'task_explain_prune_user'=>'Entfernt nicht aktivierte Benutzerkonten aus der Datenbank',
'task_info'=>'Information über die Aufgabe',
'task_interval'=>'Startintervall',
'task_last_run'=>'Zuletzt gestartet',
'task_next_run'=>'Nächster Lauf (frühestens)',
'task_seg_optimize'=>'Aufgabe: Optimiert Forum-Datenbank',
'task_seg_post_timespan'=>'Aufgabe: Kalender auf der Übersichtseite',
'task_seg_prune_log'=>'Aufgabe: Protokoll-Aufzeichnung säubern',
'task_seg_prune_request'=>'Aufgabe: Benutzeranfragen säubern',
'task_seg_prune_search'=>'Aufgabe: Suchtabelle säubern',
'task_seg_prune_user'=>'Aufgabe: Benutzerkonten säubern',
'used_ip_addresses'=>'Verwendete IP-Addressen',
'user_group'=>'Benutzergruppe',
'using_recent_forum_software_version'=>'Der Aktualisierungsserver meldet, daß du bereits die neueste verfügbare Version hast.',
'version'=>'Aktuelle Version',
'yearly'=>'Jährlich'
);
?>
